
-----------------------------------------------------------------------------------------------
 
require "Window"
require "GameLib"
require "Apollo"
require "ChatSystemLib"

local RealPing = {} 
 
local bShowFPS = true
local bShowFPSFPS = true
local bShowLatency = true
local bShowLatencyMS = true

local realFPS = 0.0
local realLatency = 0
local realPingTime = 0

realScale = 0.9

function RealPing:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 
    return o
end

function RealPing:Init()
    Apollo.RegisterAddon(self, true, "RealPing", nil)
end

-----------------------------------------------------------------------------------------------
--  Save/Restore functions on UI load
-----------------------------------------------------------------------------------------------
function RealPing:OnSave(eType)
    if eType ~= GameLib.CodeEnumAddonSaveLevel.Account then
		return
	end
	
	local locWindowLocation = self.wndMain and self.wndMain:GetLocation() or self.locSavedWindowLoc
	
	local tSaved = 
	{
		tWindowLocation = locWindowLocation and locWindowLocation:ToTable() or nil,
		nSaveVersion = knSaveVersion,
		bDisplaySetting = self.DisplayAWSetting,
	}
	
	return tSaved
end

function RealPing:OnRestore(eType,tSavedData)
    self.tSavedData = tSavedData
	if not tSavedData or tSavedData.nSaveVersion ~= knSaveVersion then
		return
	end

	if tSavedData.bDisplaySetting ~= nil then	
		self.DisplayAWSetting = tSavedData.bDisplaySetting
	end
	
	if tSavedData.tWindowLocation then
		self.locSavedWindowLoc = WindowLocation.new(tSavedData.tWindowLocation)
		
		if self.wndMain then
			self.wndMain:MoveToLocation(self.locSavedWindowLoc)
		end
	end
end 

-----------------------------------------------------------------------------------------------
-- OnLoad
-----------------------------------------------------------------------------------------------
function RealPing:OnLoad()
	self.xmlDoc = XmlDoc.CreateFromFile("RealPing.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
	
end

-----------------------------------------------------------------------------------------------
-- RealPing OnDocLoaded
-----------------------------------------------------------------------------------------------
function RealPing:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "RealPingForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		--Apollo.RegisterEventHandler("WindowManagementReady", "OnWindowManagementReady", self)
		
		self.wndMain:Show(false, true)

		self.xmlDoc = nil

		Apollo.RegisterSlashCommand("fps", "RealPingToggle", self)
		--- Menu 
	    Apollo.RegisterEventHandler("RealPingToggle", "RealPingToggle", self)
        Apollo.RegisterEventHandler("InterfaceMenuListHasLoaded", "OnInterfaceMenuListHasLoaded", self)
		
		self.timer = ApolloTimer.Create(0.5, true, "OnTimer", self)
		self.supertimer = ApolloTimer.Create(2, true, "SuperTimer", self) 
		if self.locSavedWindowLoc then
			self.wndMain:MoveToLocation(self.locSavedWindowLoc)
		end
	end
end
function RealPing:OnInterfaceMenuListHasLoaded()
	Event_FireGenericEvent("InterfaceMenuList_NewAddOn", "Real Ping. On/Off", {"RealPingToggle", "", "CRB_Basekit:kitIcon_InProgress"})
end
--[[function RealPing:OnWindowManagementReady()
    Event_FireGenericEvent("WindowManagementAdd", {wnd = self.wndMain, strName = "RealPing"})
end]]--
if wndMain ~= nil then
self.wndMain:SetScale(0.5)
end
-----------------------------------------------------------------------------------------------
-- RealPing Functions
-----------------------------------------------------------------------------------------------

function RealPing:SuperTimer()
	self.supertimer = nil
	self:ShowRealPing()
end

function RealPing:CheckLatency()
	if bShowLatency == false then
		self.wndMain:FindChild("Latency"):Show(false)
	else
		self.wndMain:FindChild("Latency"):Show(true)
	end
end

function RealPing:CheckDisplayRealPing()
	if bShowFPS == false then
		self.wndMain:Show(false, true)
		self:KillTimer()
	else
		self.wndMain:Show(true, true)
		self:RezTimer()
	end
end

function RealPing:ShowRealPing()
	self:CheckLatency()
	self:CheckDisplayRealPing()
end

function RealPing:RealPingToggle(cmd, args)
	if args == "latency" then
		self:fpsLatencyToggle()
	elseif args == "fps" then
		self:fpsTitleToggle()
	elseif args == "ms" then
		self:fpsLatencyMSToggle()
	else
		self:CheckLatency()
		if bShowFPS == false then
			self:RezTimer()
			bShowFPS = true
			self.wndMain:Show(true, true)
		elseif bShowFPS == true then
			self:KillTimer()
			bShowFPS = false
			self.wndMain:Show(false, true)
		end
	end
end
function RealPing:KillTimer()
	self.timer = nil
end

function RealPing:RezTimer()
	self.timer = ApolloTimer.Create(0.5, true, "OnTimer", self)
end

--------------------------------------------------
function RealPing:OnTimer()
    self.wndMain:FindChild("FPS"):Show(true)
    self.wndMain:FindChild("Latency"):Show(true)
	self.wndMain:FindChild("Ping"):Show(true)
	local realFPS = math.floor(GameLib.GetFrameRate() + 0.5)
	local realLatency = GameLib.GetLatency()
	local realPingTime = GameLib.GetPingTime()
	if realFPS < 15 then
		self.wndMain:FindChild("FPS"):SetTextColor("red")
		self.wndMain:FindChild("FPS"):FindChild("IconFPS"):SetBGColor("AAFF8585")
		else 
		if realFPS < 30 then
		self.wndMain:FindChild("FPS"):SetTextColor("yellow")
		self.wndMain:FindChild("FPS"):FindChild("IconFPS"):SetBGColor("AAFFEF85")
		else
		self.wndMain:FindChild("FPS"):SetTextColor("green")
		self.wndMain:FindChild("FPS"):FindChild("IconFPS"):SetBGColor("white")
	    end
    end
	self.wndMain:FindChild("FPS"):SetScale(realScale)
	self.wndMain:FindChild("FPS"):SetText("        "..realFPS.." fps")
	if realLatency  > 499 then
		self.wndMain:FindChild("Latency"):SetTextColor("red") 
		else 
		if realLatency > 99 then
		self.wndMain:FindChild("Latency"):SetTextColor("Yellow") 
		else
		self.wndMain:FindChild("Latency"):SetTextColor("green")
	    end
	end
	self.wndMain:FindChild("Latency"):SetScale(realScale)
	self.wndMain:FindChild("Latency"):SetText("        "..realLatency.." ms")
	if realPingTime  > 499 then
		self.wndMain:FindChild("Ping"):SetTextColor("red") 
		else 
		if realPingTime > 99 then
		self.wndMain:FindChild("Ping"):SetTextColor("Yellow") 
		else
		self.wndMain:FindChild("Ping"):SetTextColor("green")
	    end
	end
	self.wndMain:FindChild("Ping"):SetScale(realScale)
	self.wndMain:FindChild("Ping"):SetText("        "..realPingTime.." ms")
end


local RealPingInst = RealPing:new()
RealPingInst:Init()
